summaryrefslogtreecommitdiff
path: root/render/box.h
diff options
context:
space:
mode:
Diffstat (limited to 'render/box.h')
-rw-r--r--render/box.h13
1 files changed, 9 insertions, 4 deletions
diff --git a/render/box.h b/render/box.h
index a0c43ef1e..369956f76 100644
--- a/render/box.h
+++ b/render/box.h
@@ -60,15 +60,19 @@
* A box tree is "normalized" if the following is satisfied:
* \code
* parent permitted child nodes
* BLOCK, INLINE_BLOCK BLOCK, INLINE_CONTAINER, TABLE
* INLINE_CONTAINER INLINE, INLINE_BLOCK, FLOAT_LEFT, FLOAT_RIGHT, BR, TEXT,
* INLINE_END
* INLINE none
* TABLE at least 1 TABLE_ROW_GROUP
* TABLE_ROW_GROUP at least 1 TABLE_ROW
* TABLE_ROW at least 1 TABLE_CELL
* TABLE_CELL BLOCK, INLINE_CONTAINER, TABLE (same as BLOCK)
* FLOAT_(LEFT|RIGHT) exactly 1 BLOCK or TABLE \endcode
*/
#ifndef _NETSURF_RENDER_BOX_H_
@@ -93,7 +97,8 @@ typedef enum {
BOX_TABLE_ROW_GROUP,
BOX_FLOAT_LEFT, BOX_FLOAT_RIGHT,
BOX_INLINE_BLOCK, BOX_BR, BOX_TEXT,
- BOX_INLINE_END
+ BOX_INLINE_END,
+ BOX_LIST, BOX_LIST_ITEM, BOX_LIST_MARKER, BOX_LIST_PRINCIPAL
} box_type;
struct rect {
@@ -60,15 +60,19 @@
* \code
* parent permitted child nodes
- * BLOCK, INLINE_BLOCK BLOCK, INLINE_CONTAINER, TABLE
+ * BLOCK, INLINE_BLOCK BLOCK, INLINE_CONTAINER, TABLE, LIST
* INLINE_CONTAINER INLINE, INLINE_BLOCK, FLOAT_LEFT, FLOAT_RIGHT, BR, TEXT,
* INLINE_END
@@ -60,15 +60,19 @@
* TABLE_ROW_GROUP at least 1 TABLE_ROW
* TABLE_ROW at least 1 TABLE_CELL
- * TABLE_CELL BLOCK, INLINE_CONTAINER, TABLE (same as BLOCK)
- * FLOAT_(LEFT|RIGHT) exactly 1 BLOCK or TABLE \endcode
+ * TABLE_CELL BLOCK, INLINE_CONTAINER, TABLE, LIST (same as BLOCK)
+ * FLOAT_(LEFT|RIGHT) exactly 1 BLOCK or TABLE
+ * LIST at least 1 LIST_ITEM
+ * LIST_ITEM exactly 1 LIST_MARKER and exactly 1 LIST_PRINCIPAL
+ * LIST_PRINCIPAL BLOCK, INLINE_CONTAINER, TABLE, LIST (same as BLOCK)
+ * \endcode
*/
#ifndef _NETSURF_RENDER_BOX_H_